@@ -8,6 +8,8 @@ import urllib3
 from palp import settings
 from typing import Callable
 from urllib.parse import urlparse
+
+from palp.network.meta import Meta
 from palp.network.response import Response
 from palp.tool.user_agent import random_ua
 from requests.cookies import RequestsCookieJar
@@ -50,6 +52,7 @@ class Request:
         'cookie_jar',
         'priority',
         'command',
+        'meta'
     ]
 
     # 下载器
@@ -91,6 +94,7 @@ class Request:
             timeout=None,
             proxies=None,
             json=None,
+            meta: Meta = None,
             downloader=None,
             downloader_parser=None,
             filter_repeat: bool = False,
@@ -122,6 +126,7 @@ class Request:
         :param command: 自定义操作命令，用于自定义 downloader 时使用
         :param downloader: 自定义的下载器（局部）
         :param downloader_parser: 自定义的下载器的解析器（局部）
+        :param meta: 自动向下传递参数，临时的直接 xxx=yyy，自动的 meta=yyy
 
         Palp 参数（非用户设置）
         :param cookie_jar: cookie_jar，存储 cookie，这里使用的是 requests 模块的，其它请求的话可以自己提取
@@ -132,6 +137,7 @@ class Request:
 
         # Request 所需字段
         self._requests_params = {}  # request 参数
+        self.meta = meta
         self.command = command
         self.callback = callback
         self.priority = priority
@@ -205,6 +211,8 @@ class Request:
             self.method = 'GET'
 
         # 设置默认
+        if self.meta is None:
+            self.meta = Meta()
         if self.downloader is None:
             self.downloader = self.__class__.DOWNLOADER
         if self.downloader_parser is None:
@@ -264,6 +272,10 @@ class Request:
             elif key.startswith('_') or not value:
                 continue
 
+            # meta 转为字典
+            elif key == 'meta':
+                request_dict[key] = value.to_dict()
+
             # priority 默认值的情况直接忽略
             elif key == 'priority' and value == settings.DEFAULT_QUEUE_PRIORITY:
                 continue
@@ -379,8 +391,13 @@ class LoadRequest:
 
         # 处理请求导入
         for key, value in kwargs.items():
+            # 导入 meta
+            if key == 'meta':
+                kwargs[key] = Meta()
+                kwargs[key].update(value)
+
             # 导入 cookie_jar
-            if key == 'cookie_jar':
+            elif key == 'cookie_jar':
                 kwargs[key] = RequestsCookieJar()
                 kwargs[key].update(value)
 
